<?php

namespace App\Http\Controllers\Admin;

use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Gate;
use App\Http\Controllers\Controller;
use App\Http\Requests\Admin\StoreUsersRequest;
use App\Http\Requests\Admin\UpdateUsersRequest;

use Spatie\Permission\Models\Role;
use Spatie\Permission\Models\Permission;
use DB;
use Hash;
use DataTables;


use App\Imports\UsersImport;
use Maatwebsite\Excel\Facades\Excel;
use Illuminate\Support\Arr;

use Brian2694\Toastr\Facades\Toastr;

class UsersController extends Controller
{
    /**
     * Display a listing of User.
     *
     * @return \Illuminate\Http\Response
     */



    public function index(Request $request)
    {

        $users = User::all();

        return view('admin.users.index', compact('users'));
    }

    /**
     * Show the form for creating new User.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {

        $roles = Role::get()->pluck('name', 'name');

        return view('admin.users.create', compact('roles'));
    }

    /**
     * Store a newly created User in storage.
     *
     * @param  \App\Http\Requests\StoreUsersRequest  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request, User $users)
    {
        /*
        $this->validate($request, [
            'name' => 'required',
            'email' => 'required|email|unique:users,email',
            'password' => 'required|same:confirm-password',
            'roles' => 'required'
        ]);
        */
    
        $input = $request->all();
        $input['password'] = Hash::make($input['password']);
    

        $users->fname = $request->fname;
        $users->mname = $request->mname;
        $users->lname = $request->lname;
        $name = strtolower($request->fname). " ". strtolower(substr($request->mname, 0, 1)). ". ". strtolower($request->lname);
        $name = ucwords($name);
        $users->name = $name;

        if ($request->hasFile('user_photo')){
            if($request->user_photo->getClientOriginalName())
            {
                $ext = $request->user_photo->getClientOriginalExtension();
                $user_photo = $name.'.'.$ext;
                $request->user_photo->storeAs('public/users', $user_photo);
            }else{
                $user_photo='user.png';            
            }
        } else {
           $user_photo='user.png';        
        }

        $users->user_photo = $user_photo;
        
        $users->email = $request->email;
        $users->password = Hash::make($request->password);
        $users->mobilenumber = $request->mobilenumber;
        $users->phonenumber = $request->phonenumber;
        $users->birthdate = $request->birthdate;
        $users->birthplace = $request->birthplace;
        $users->save();

        //$user = User::create($input);
        $users->assignRole($request->input('roles'));

        Toastr::success('User Added Successfully :)','User Management');

        return redirect()->route('admin.users.index')
                        ->with('success','User created successfully');
                        
    }


    /**
     * Show the form for editing User.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(User $user)
    {

        $roles = Role::get()->pluck('name', 'name');

        return view('admin.users.edit', compact('user', 'roles'));
    }

    /**
     * Update User in storage.
     *
     * @param  \App\Http\Requests\UpdateUsersRequest  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        /*
        $this->validate($request, [
            'name' => 'required',
            'email' => 'required|email|unique:users,email,'.$id,
            'password' => 'same:confirm-password',
            'roles' => 'required'
        ]);
        */
    
        /*
        $input = $request->all();
        if(!empty($input['password'])){ 
            $input['password'] = Hash::make($input['password']);
        }else{
            $input = Arr::except($input,array('password'));    
        }
        */

        $users = User::where('id', '=', $id)->first(); 



        $users->fname = $request->fname;
        $users->mname = $request->mname;
        $users->lname = $request->lname;
        $name = strtolower($request->fname). " ". strtolower(substr($request->mname, 0, 1)). ". ". strtolower($request->lname);
        $name = ucwords($name);
        $users->name = $name;

        if ($request->hasFile('user_photo')){
            if($request->user_photo->getClientOriginalName())
            {
                $ext = $request->user_photo->getClientOriginalExtension();
                $user_photo = $request->name.'.'.$ext;
                $request->user_photo->storeAs('public/users', $user_photo);
            }else{
                $user_photo='';            
            }
        } else {
            $user_photo='';        
        }

    
        //$user = User::find($id);
        //$user->update($input);
        if ($request->hasFile('user_photo')){
            $users->user_photo = $user_photo;    
        } 


        
        $users->email = $request->email;
        $users->mobilenumber = $request->mobilenumber;
        $users->phonenumber = $request->phonenumber;
        $users->birthdate = $request->birthdate;
        $users->birthplace = $request->birthplace;

        if($request->password != ""){
            $users->password = Hash::make($request->password);
        }
        $users->save();

        DB::table('model_has_roles')->where('model_id',$id)->delete();
    
        $users->assignRole($request->input('roles'));
        

        Toastr::success('User updated Successfully :)','User Management');

        return redirect()->route('admin.users.index')
                        ->with('success','User updated successfully');
    }

    public function show(User $user)
    {


        $roles = Role::get()->pluck('name', 'name');

        return view('admin.users.show', compact('user', 'roles'));
    }

    /**
     * Remove User from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(User $user)
    {
        $user->delete();
        Toastr::warning('User deleted Successfully :)','User Management');
        return redirect()->route('admin.users.index');
    }

    /**
     * Delete all selected User at once.
     *
     * @param Request $request
     */
    public function massDestroy(Request $request)
    {

        User::whereIn('id', request('ids'))->delete();

        return response()->noContent();
    }


   public function allUsers(Request $request)
    {
        
        $columns = array( 
                            0 =>'id', 
                            1 =>'name',
                            2=> 'email',
                            3=> 'name'
                        );
  
        $totalData = User::count();
            
        $totalFiltered = $totalData; 

        $limit = $request->input('length');
        $start = $request->input('start');
        $order = $columns[$request->input('order.0.column')];
        $dir = $request->input('order.0.dir');
            
        if(empty($request->input('search.value')))
        {            
            $posts = User::offset($start)
                         ->limit($limit)
                         //->orderBy($order,$dir)
                         ->orderBy('name',"ASC")
                         ->get();
        }
        else {
            $search = $request->input('search.value'); 

            $posts =  User::where('id','LIKE',"%{$search}%")
                            ->orWhere('name', 'LIKE',"%{$search}%")
                            ->orWhere('email', 'LIKE',"%{$search}%")
                            ->orWhere('name', 'LIKE',"%{$search}%")
                            ->offset($start)
                            ->limit($limit)
                            ->orderBy($order,$dir)
                            ->get();

            $totalFiltered = User::where('id','LIKE',"%{$search}%")
                             ->orWhere('name', 'LIKE',"%{$search}%")
                             ->orWhere('email', 'LIKE',"%{$search}%")
                             ->orWhere('name', 'LIKE',"%{$search}%")
                             ->count();
        }

        $data = array();
        if(!empty($posts))
        {
            foreach ($posts as $post)
            {
                $show =  route('admin.users.show',$post->id);
                $edit =  route('admin.users.edit',$post->id);
                $delete =  route('admin.users.destroy',$post->id);
                $token =  csrf_token();

                   
                  $roles = "";
                  foreach($post->roles()->pluck('name') as $role){
                        $roles = $roles. '<span class="badge badge-info">'.$role. '</span>';   
                   }; 

                   $row[6] = $roles;
                                          


                $nestedData['id'] = $post->id;
                $nestedData['user_photo'] = $post->user_photo;
                $nestedData['name'] = $post->name;
                $nestedData['email'] = $post->email;
                //foreach ($post->roles()->pluck('name') as $role){
                //    $nestedData['role'] = $role;
                //}
                $nestedData['role'] = $row[6];


                $nestedData['options'] = "<a href='{$show}' title='View' class='m-r-15 crm-action-edit text-muted'><i class='fas fa-desktop'></i></a>  &nbsp;<a href='{$edit}' title='Edit' class='m-r-15 crm-action-edit text-muted'><i class='fas fa-edit'></i></a> ". 
                    "<form action='{$delete}' name='deleteform' method='POST' onsubmit=\"return confirm('Are you sure you want to Delete Selected Record?');\" style='display: inline-block;'>".
                        "<input type='hidden' name='_method' value='DELETE'>".
                        "<input type='hidden' name='_token' value='{$token}'>". 
                        "<button type='submit' title = 'Delete' class='crm-action-delete text-muted' style='border:none; background:none; cursor:pointer;'><i class='fas fa-trash'></i></button>".
                    "</form>";
                $data[] = $nestedData;

            }
        }
          
        $json_data = array(
                    "draw"            => intval($request->input('draw')),  
                    "recordsTotal"    => intval($totalData),  
                    "recordsFiltered" => intval($totalFiltered), 
                    "data"            => $data   
                    );
            
        echo json_encode($json_data); 
        
    }    

    public function notifications()
    {
        return auth()->user()->Notifications()->get()->toArray();
    }   

    public function import() 
    {

        Excel::import(new UsersImport,request()->file('file'));
        return back();
    }   

    public function importExportView()
    {

       return view('admin.users.import');
    }    


}
