@extends('layouts.main') 
@section('title', 'New RX Product')
@section('content')

    <!-- push external head elements to head -->
    @push('head')
        <link rel="stylesheet" href="{{ asset('plugins/select2/dist/css/select2.min.css') }}">
        <link rel="stylesheet" href="{{ asset('plugins/summernote/dist/summernote-bs4.css') }}">
        <link rel="stylesheet" href="{{ asset('plugins/bootstrap-tagsinput/dist/bootstrap-tagsinput.css') }}">
        <link rel="stylesheet" href="{{ asset('plugins/mohithg-switchery/dist/switchery.min.css') }}">
    @endpush

    <div class="container-fluid">
        <div class="page-header">
            <div class="row align-items-end">
                <div class="col-lg-8">
                    <div class="page-header-title">
                        <i class="ik ik-user-plus bg-blue"></i>
                        <div class="d-inline">
                            <h5>{{ __('New RX Product')}}</h5>
                            <span>{{ __('Add New RX Product')}}</span>
                        </div>
                    </div>
                </div>
                <div class="col-lg-4">
                    <nav class="breadcrumb-container" aria-label="breadcrumb">
                        <ol class="breadcrumb">
                            <li class="breadcrumb-item">
                                <a href="{{route('home')}}"><i class="ik ik-home"></i></a>
                            </li>
                            <li class="breadcrumb-item"><a href="{{ route('admin.rxproducts.index') }}">{{ __('List of RX Product')}}</a></li>
                            <li class="breadcrumb-item active" aria-current="page">{{ __('New RX Product')}}</li>
                        </ol>
                    </nav>
                </div>
            </div>
        </div>

        <form method="post" action="{{ route('admin.rxproducts.store') }}" enctype="multipart/form-data" onsubmit="return validateForm()">
            <input type="hidden" class="form-control form-control-sm" id= "_token" name="_token" value="{{ csrf_token() }}">

            <div class="row">



                <div class="col-md-6">
                    <div class="card">
                        <div class="card-header"><h3>{{ __('RX Product Information')}}</h3></div>
                        <div class="card-body">
                            <div class="row">

                                <div class="col-md-12">
                                    <div class="row">
                                        <div class="col-sm-3">
                                            <!-- text input -->
                                            <div class="form-group">
                                              <label for="exampleInputName1">{{ __('SKU')}}</label>
                                              <input type="text" class="form-control" id="sku" name="sku" placeholder="SKU" required>
                                            </div>
                                        </div>
                                        <div class="col-sm-9">
                                            <div class="form-group">
                                                <label>Product Name</label>
                                                <input type="text" class="form-control" id="product_name" name="product_name" placeholder="Product Name" required>
                                            </div>
                                        </div>
                                    </div>   
                                    <div class="row">
                                        <div class="col-sm-6">
                                            <!-- text input -->
                                            <div class="form-group">
                                              <label for="exampleInputName1">{{ __('Price')}}</label>
                                              <input type="number" class="form-control" id="price" name="price" placeholder="0.00" style="text-align: right;" required>
                                            </div>
                                        </div>
                                        <div class="col-sm-6">
                                            <div class="form-group">
                                                <label>Cost Price</label>
                                                <input type="number" class="form-control" id="cost_price" name="cost_price" placeholder="0.00" style="text-align: right;"  required>
                                            </div>
                                        </div>
                                    </div>  
                                    <div class="row">
                                        <div class="col-sm-6">
                                            <!-- text input -->
                                            <div class="form-group">
                                              <label for="exampleInputName1">{{ __('Retail Price')}}</label>
                                              <input type="number" class="form-control" id="retail_price" name="retail_price" placeholder="0.00" style="text-align: right;"  required>
                                            </div>
                                        </div>
                                        <div class="col-sm-6">
                                            <div class="form-group">
                                                <label>Sale Price</label>
                                                <input type="number" class="form-control" id="sale_price" name="sale_price" placeholder="0.00" style="text-align: right;" required>
                                            </div>
                                        </div>
                                    </div>  
                                    <div class="form-group">
                                        <label for="exampleInputName1">{{ __('Category')}}</label>
                                        <textarea class="form-control" id="category" name = "category" rows="3"></textarea>
                                    </div>

                                    <div class="row">
                                        <div class="col-sm-9">
                                            <!-- text input -->
                                            <div class="form-group">
                                              <label for="exampleInputName1">{{ __('Product Image')}}</label>
                                              <input type="text" class="form-control" id="prod_image" name="prod_image" placeholder="Product Image">
                                            </div>
                                        </div>
                                        <div class="col-sm-3">
                                            <div class="form-group">
                                                <label>Visibility</label>
                                                <select name="visibility" id="visibility" class="form-control select2" required>
                                                    <option value="">Select Visibility</option>
                                                    <option value="Y">Visible</option>
                                                    <option value="N">Hidden</option>
                                                </select> 
                                            </div>
                                        </div>
                                    </div> 

                                    <button type="submit" class="btn btn-primary mr-2">{{ __('Submit')}}</button>
                                    <button type="button" class="btn btn-light" onclick="window.location.href='{{ route('admin.rxproducts.index') }}'">{{ __('Cancel')}}</button>

                                </div>
                            </div>
                        </div>
                    </div>
                </div>


            </div>
        </form>
        
    </div>

    <!-- push external js -->
    @push('script')
        <script src="{{ asset('plugins/select2/dist/js/select2.min.js') }}"></script>
        <script src="{{ asset('plugins/summernote/dist/summernote-bs4.min.js') }}"></script>
        <script src="{{ asset('plugins/bootstrap-tagsinput/dist/bootstrap-tagsinput.min.js') }}"></script>
        <script src="{{ asset('plugins/jquery.repeater/jquery.repeater.min.js') }}"></script>
        <script src="{{ asset('plugins/mohithg-switchery/dist/switchery.min.js') }}"></script>
      
        <script src="{{ asset('js/form-advanced.js') }}"></script>

        <script>
        function validateForm() {

          
          if(document.getElementById('sku').value == ""){
              alert("Please Enter SKU to Continue!");
               return false;
          }
          if(document.getElementById('product_name').value == ""){
              alert("Please Enter Product Name to Continue!");
               return false;
          }
          if(document.getElementById('price').value == ""){
              alert("Please Enter Price to Continue!");
               return false;
          }          
          if(document.getElementById('cost_price').value == ""){
              alert("Please Enter Cost Price to Continue!");
               return false;
          }
          if(document.getElementById('retail_price').value == ""){
              alert("Please Enter Retail Price to Continue!");
               return false;
          }  
          if(document.getElementById('sale_price').value == ""){
              alert("Please Enter Sale Price to Continue!");
               return false;
          }  
          if(document.getElementById('visibility').value == ""){
              alert("Please Select Visibility to Continue!");
               return false;
          } 
          
          var ok = confirm("Are you sure you want Save Record?");
          if(ok){  
            return true; 
          } else {  
            return false; 
          }
        }
        </script>

        <script language="javascript"> 
        function openWindow() { 
          window.open("{{route('tablelist.allusers.index')}}", "_blank", "toolbar=yes, scrollbars=yes, resizable=yes, top=100, left=200, width=1200, height=650"); 
        } 
        </script>    

        <script>
        function cleartext1() {
          document.getElementById('user_id').value = "";
          document.getElementById('name').value = "";
        }
        </script>

    @endpush
@endsection
    
